MVVM Library for Python
=======================

# Introduction

`nova-mvvm` is a Python package designed to simplify the implementation of the Model-View-ViewModel (MVVM) pattern.
This library provides tools and utilities that help in building clean, scalable, and maintainable GUI applications using MVVM architecture in Python.
It currently supports pyqt5, pyqt6, [Trame](https://github.com/Kitware/trame) and [Panel](https://github.com/holoviz/panel) GUI frameworks.
